@@ -1,16 +1,12 @@
 package SDL::Event;
 use strict;
 use warnings;
-use vars qw($VERSION $XS_VERSION @ISA @EXPORT @EXPORT_OK);
+use vars qw(@ISA @EXPORT @EXPORT_OK);
 require Exporter;
 require DynaLoader;
 use SDL::Constants ':SDL::Events';
 our @ISA = qw(Exporter DynaLoader);
 
-our $VERSION    = '2.541_10';
-our $XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
-
 use SDL::Internal::Loader;
 internal_load_dlls(__PACKAGE__);
 
@@ -27,9 +23,8 @@ our %EXPORT_TAGS = (
 	hat    => $SDL::Constants::EXPORT_TAGS{'SDL::Events/hat'},
 	app    => $SDL::Constants::EXPORT_TAGS{'SDL::Events/app'},
 	button => $SDL::Constants::EXPORT_TAGS{'SDL::Events/button'},
-	keysym => $SDL::Constants::EXPORT_TAGS{'SDL::Events/keysym'},
-	keymod => $SDL::Constants::EXPORT_TAGS{'SDL::Events/keymod'},
-	repeat => $SDL::Constants::EXPORT_TAGS{'SDL::Events/repeat'}
+	keysym => $SDL::Constants::EXPORT_TAGS{'SDL::Events/meysym'},
+	keymod => $SDL::Constants::EXPORT_TAGS{'SDL::Events/keymod'}
 );
 
 1;
